pub struct DataCursorSnapshot {
pub marker_seq: u64,
pub event_seq_before: u64,
pub ts_init: UnixNanos,
pub advanced: Vec<StreamCursor>,
}Expand description
A snapshot of the cursor positions for all active market-data streams at a marker point.
Fields
marker_seq: u64Monotonic sequence of this marker within the sidecar.
event_seq_before: u64The event-store sequence before which this snapshot was taken.
ts_init: UnixNanosThe ts_init at the point this snapshot was taken.
advanced: Vec<StreamCursor>The cursors for every stream slot that advanced since the previous snapshot.