pub struct JoinedStream {
pub entry: StreamDictEntry,
pub cursor: StreamCursor,
pub records: Vec<CatalogReplayRecord>,
pub candidate: bool,
}Expand description
Catalog rows joined to one folded marker stream cursor.
Fields
entry: StreamDictEntryStream dictionary entry for the folded cursor.
cursor: StreamCursorFolded cursor for the requested event-store boundary.
records: Vec<CatalogReplayRecord>Catalog rows selected for replayable data classes.
candidate: boolWhether the catalog row count disagrees with the folded marker count.