pub struct MarkerGap {
pub from_marker_seq: u64,
pub to_marker_seq: u64,
pub reason: MarkerGapReason,
}Expand description
A gap in the sidecar marker sequence.
Fields
from_marker_seq: u64The first marker sequence number missing from the sequence.
to_marker_seq: u64The last marker sequence number missing from the sequence.
reason: MarkerGapReasonThe reason this gap was recorded.